Module: Aws::SageMakerGeospatial

Defined in:
lib/aws-sdk-sagemakergeospatial/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/params.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-sagemakergeospatial/plugins/endpoints.rb,
lib/aws-sdk-sagemakergeospatial/endpoint_provider.rb,
lib/aws-sdk-sagemakergeospatial/client_api.rb,
lib/aws-sdk-sagemakergeospatial/endpoints.rb,
lib/aws-sdk-sagemakergeospatial/resource.rb,
lib/aws-sdk-sagemakergeospatial/errors.rb,
lib/aws-sdk-sagemakergeospatial/client.rb,
lib/aws-sdk-sagemakergeospatial/types.rb,
lib/aws-sdk-sagemakergeospatial.rb

Overview

This module provides support for Amazon SageMaker geospatial capabilities. This module is available in the aws-sdk-sagemakergeospatial gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

sage_maker_geospatial = Aws::SageMakerGeospatial::Client.new
resp = sage_maker_geospatial.delete_earth_observation_job(params)

See Client for more information.

Errors

Errors returned from Amazon SageMaker geospatial capabilities are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::SageMakerGeospatial::Errors::ServiceError
  # rescues all Amazon SageMaker geospatial capabilities API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Params, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.48.0'