Class: Aws::SageMakerGeospatial::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SageMakerGeospatial::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sagemakergeospatial/client.rb,
sig/client.rbs
Overview
An API client for SageMakerGeospatial. To construct a client, you need to configure a :region and :credentials.
client = Aws::SageMakerGeospatial::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _DeleteEarthObservationJobResponseSuccess, _DeleteVectorEnrichmentJobResponseSuccess, _ExportEarthObservationJobResponseSuccess, _ExportVectorEnrichmentJobResponseSuccess, _GetEarthObservationJobResponseSuccess, _GetRasterDataCollectionResponseSuccess, _GetTileResponseSuccess, _GetVectorEnrichmentJobResponseSuccess, _ListEarthObservationJobsResponseSuccess, _ListRasterDataCollectionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVectorEnrichmentJobsResponseSuccess, _SearchRasterDataCollectionResponseSuccess, _StartEarthObservationJobResponseSuccess, _StartVectorEnrichmentJobResponseSuccess, _StopEarthObservationJobResponseSuccess, _StopVectorEnrichmentJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_earth_observation_job(params = {}) ⇒ Struct
Use this operation to delete an Earth Observation job.
-
#delete_vector_enrichment_job(params = {}) ⇒ Struct
Use this operation to delete a Vector Enrichment job.
-
#export_earth_observation_job(params = {}) ⇒ Types::ExportEarthObservationJobOutput
Use this operation to export results of an Earth Observation job and optionally source images used as input to the EOJ to an Amazon S3 location.
-
#export_vector_enrichment_job(params = {}) ⇒ Types::ExportVectorEnrichmentJobOutput
Use this operation to copy results of a Vector Enrichment job to an Amazon S3 location.
-
#get_earth_observation_job(params = {}) ⇒ Types::GetEarthObservationJobOutput
Get the details for a previously initiated Earth Observation job.
-
#get_raster_data_collection(params = {}) ⇒ Types::GetRasterDataCollectionOutput
Use this operation to get details of a specific raster data collection.
-
#get_tile(params = {}) ⇒ Types::GetTileOutput
Gets a web mercator tile for the given Earth Observation job.
-
#get_vector_enrichment_job(params = {}) ⇒ Types::GetVectorEnrichmentJobOutput
Retrieves details of a Vector Enrichment Job for a given job Amazon Resource Name (ARN).
-
#list_earth_observation_jobs(params = {}) ⇒ Types::ListEarthObservationJobOutput
Use this operation to get a list of the Earth Observation jobs associated with the calling Amazon Web Services account.
-
#list_raster_data_collections(params = {}) ⇒ Types::ListRasterDataCollectionsOutput
Use this operation to get raster data collections.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to the resource.
-
#list_vector_enrichment_jobs(params = {}) ⇒ Types::ListVectorEnrichmentJobOutput
Retrieves a list of vector enrichment jobs.
-
#search_raster_data_collection(params = {}) ⇒ Types::SearchRasterDataCollectionOutput
Allows you run image query on a specific raster data collection to get a list of the satellite imagery matching the selected filters.
-
#start_earth_observation_job(params = {}) ⇒ Types::StartEarthObservationJobOutput
Use this operation to create an Earth observation job.
-
#start_vector_enrichment_job(params = {}) ⇒ Types::StartVectorEnrichmentJobOutput
Creates a Vector Enrichment job for the supplied job type.
-
#stop_earth_observation_job(params = {}) ⇒ Struct
Use this operation to stop an existing earth observation job.
-
#stop_vector_enrichment_job(params = {}) ⇒ Struct
Stops the Vector Enrichment job for a given job ARN.
-
#tag_resource(params = {}) ⇒ Struct
The resource you want to tag.
-
#untag_resource(params = {}) ⇒ Struct
The resource you want to untag.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1778 1779 1780 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1778 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1781 1782 1783 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1781 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1751 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SageMakerGeospatial') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sagemakergeospatial' context[:gem_version] = '1.48.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_earth_observation_job(params = {}) ⇒ Struct
Use this operation to delete an Earth Observation job.
85 |
# File 'sig/client.rbs', line 85
def delete_earth_observation_job: (
|
#delete_vector_enrichment_job(params = {}) ⇒ Struct
Use this operation to delete a Vector Enrichment job.
94 |
# File 'sig/client.rbs', line 94
def delete_vector_enrichment_job: (
|
#export_earth_observation_job(params = {}) ⇒ Types::ExportEarthObservationJobOutput
Use this operation to export results of an Earth Observation job and optionally source images used as input to the EOJ to an Amazon S3 location.
109 |
# File 'sig/client.rbs', line 109
def export_earth_observation_job: (
|
#export_vector_enrichment_job(params = {}) ⇒ Types::ExportVectorEnrichmentJobOutput
Use this operation to copy results of a Vector Enrichment job to an Amazon S3 location.
132 |
# File 'sig/client.rbs', line 132
def export_vector_enrichment_job: (
|
#get_earth_observation_job(params = {}) ⇒ Types::GetEarthObservationJobOutput
Get the details for a previously initiated Earth Observation job.
163 |
# File 'sig/client.rbs', line 163
def get_earth_observation_job: (
|
#get_raster_data_collection(params = {}) ⇒ Types::GetRasterDataCollectionOutput
Use this operation to get details of a specific raster data collection.
180 |
# File 'sig/client.rbs', line 180
def get_raster_data_collection: (
|
#get_tile(params = {}) ⇒ Types::GetTileOutput
Gets a web mercator tile for the given Earth Observation job.
190 |
# File 'sig/client.rbs', line 190
def get_tile: (
|
#get_vector_enrichment_job(params = {}) ⇒ Types::GetVectorEnrichmentJobOutput
Retrieves details of a Vector Enrichment Job for a given job Amazon Resource Name (ARN).
224 |
# File 'sig/client.rbs', line 224
def get_vector_enrichment_job: (
|
#list_earth_observation_jobs(params = {}) ⇒ Types::ListEarthObservationJobOutput
Use this operation to get a list of the Earth Observation jobs associated with the calling Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
235 |
# File 'sig/client.rbs', line 235
def list_earth_observation_jobs: (
|
#list_raster_data_collections(params = {}) ⇒ Types::ListRasterDataCollectionsOutput
Use this operation to get raster data collections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
250 |
# File 'sig/client.rbs', line 250
def list_raster_data_collections: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to the resource.
261 |
# File 'sig/client.rbs', line 261
def list_tags_for_resource: (
|
#list_vector_enrichment_jobs(params = {}) ⇒ Types::ListVectorEnrichmentJobOutput
Retrieves a list of vector enrichment jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
272 |
# File 'sig/client.rbs', line 272
def list_vector_enrichment_jobs: (
|
#search_raster_data_collection(params = {}) ⇒ Types::SearchRasterDataCollectionOutput
Allows you run image query on a specific raster data collection to get a list of the satellite imagery matching the selected filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
288 |
# File 'sig/client.rbs', line 288
def search_raster_data_collection: (
|
#start_earth_observation_job(params = {}) ⇒ Types::StartEarthObservationJobOutput
Use this operation to create an Earth observation job.
317 |
# File 'sig/client.rbs', line 317
def start_earth_observation_job: (
|
#start_vector_enrichment_job(params = {}) ⇒ Types::StartVectorEnrichmentJobOutput
Creates a Vector Enrichment job for the supplied job type. Currently, there are two supported job types: reverse geocoding and map matching.
411 |
# File 'sig/client.rbs', line 411
def start_vector_enrichment_job: (
|
#stop_earth_observation_job(params = {}) ⇒ Struct
Use this operation to stop an existing earth observation job.
445 |
# File 'sig/client.rbs', line 445
def stop_earth_observation_job: (
|
#stop_vector_enrichment_job(params = {}) ⇒ Struct
Stops the Vector Enrichment job for a given job ARN.
454 |
# File 'sig/client.rbs', line 454
def stop_vector_enrichment_job: (
|
#tag_resource(params = {}) ⇒ Struct
The resource you want to tag.
463 |
# File 'sig/client.rbs', line 463
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
The resource you want to untag.
473 |
# File 'sig/client.rbs', line 473
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1771 1772 1773 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1771 def waiter_names [] end |