Class: Aws::SageMakerGeospatial::Types::VectorEnrichmentJobDataSourceConfigInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-sagemakergeospatial/types.rb

Overview

Note:

VectorEnrichmentJobDataSourceConfigInput is a union - when making an API calls you must set exactly one of the members.

Note:

VectorEnrichmentJobDataSourceConfigInput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of VectorEnrichmentJobDataSourceConfigInput corresponding to the set member.

The input structure for the data source that represents the storage type of the input data objects.

Defined Under Namespace

Classes: S3Data, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_dataTypes::VectorEnrichmentJobS3Data

The input structure for the Amazon S3 data that represents the Amazon S3 location of the input data objects.



2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-sagemakergeospatial/types.rb', line 2430

class VectorEnrichmentJobDataSourceConfigInput < Struct.new(
  :s3_data,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3Data < VectorEnrichmentJobDataSourceConfigInput; end
  class Unknown < VectorEnrichmentJobDataSourceConfigInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2430
2431
2432
# File 'lib/aws-sdk-sagemakergeospatial/types.rb', line 2430

def unknown
  @unknown
end