Class: Aws::SageMakerGeospatial::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SageMakerGeospatial::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sagemakergeospatial/client.rb
Overview
An API client for SageMakerGeospatial. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SageMakerGeospatial::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_earth_observation_job(params = {}) ⇒ Struct
Use this operation to delete an Earth Observation job.
-
#delete_vector_enrichment_job(params = {}) ⇒ Struct
Use this operation to delete a Vector Enrichment job.
-
#export_earth_observation_job(params = {}) ⇒ Types::ExportEarthObservationJobOutput
Use this operation to export results of an Earth Observation job and optionally source images used as input to the EOJ to an Amazon S3 location.
-
#export_vector_enrichment_job(params = {}) ⇒ Types::ExportVectorEnrichmentJobOutput
Use this operation to copy results of a Vector Enrichment job to an Amazon S3 location.
-
#get_earth_observation_job(params = {}) ⇒ Types::GetEarthObservationJobOutput
Get the details for a previously initiated Earth Observation job.
-
#get_raster_data_collection(params = {}) ⇒ Types::GetRasterDataCollectionOutput
Use this operation to get details of a specific raster data collection.
-
#get_tile(params = {}) ⇒ Types::GetTileOutput
Gets a web mercator tile for the given Earth Observation job.
-
#get_vector_enrichment_job(params = {}) ⇒ Types::GetVectorEnrichmentJobOutput
Retrieves details of a Vector Enrichment Job for a given job Amazon Resource Name (ARN).
-
#list_earth_observation_jobs(params = {}) ⇒ Types::ListEarthObservationJobOutput
Use this operation to get a list of the Earth Observation jobs associated with the calling Amazon Web Services account.
-
#list_raster_data_collections(params = {}) ⇒ Types::ListRasterDataCollectionsOutput
Use this operation to get raster data collections.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to the resource.
-
#list_vector_enrichment_jobs(params = {}) ⇒ Types::ListVectorEnrichmentJobOutput
Retrieves a list of vector enrichment jobs.
-
#search_raster_data_collection(params = {}) ⇒ Types::SearchRasterDataCollectionOutput
Allows you run image query on a specific raster data collection to get a list of the satellite imagery matching the selected filters.
-
#start_earth_observation_job(params = {}) ⇒ Types::StartEarthObservationJobOutput
Use this operation to create an Earth observation job.
-
#start_vector_enrichment_job(params = {}) ⇒ Types::StartVectorEnrichmentJobOutput
Creates a Vector Enrichment job for the supplied job type.
-
#stop_earth_observation_job(params = {}) ⇒ Struct
Use this operation to stop an existing earth observation job.
-
#stop_vector_enrichment_job(params = {}) ⇒ Struct
Stops the Vector Enrichment job for a given job ARN.
-
#tag_resource(params = {}) ⇒ Struct
The resource you want to tag.
-
#untag_resource(params = {}) ⇒ Struct
The resource you want to untag.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1778 1779 1780 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1778 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1781 1782 1783 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1781 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1751 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SageMakerGeospatial') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sagemakergeospatial' context[:gem_version] = '1.46.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_earth_observation_job(params = {}) ⇒ Struct
Use this operation to delete an Earth Observation job.
495 496 497 498 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 495 def delete_earth_observation_job(params = {}, = {}) req = build_request(:delete_earth_observation_job, params) req.send_request() end |
#delete_vector_enrichment_job(params = {}) ⇒ Struct
Use this operation to delete a Vector Enrichment job.
518 519 520 521 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 518 def delete_vector_enrichment_job(params = {}, = {}) req = build_request(:delete_vector_enrichment_job, params) req.send_request() end |
#export_earth_observation_job(params = {}) ⇒ Types::ExportEarthObservationJobOutput
Use this operation to export results of an Earth Observation job and optionally source images used as input to the EOJ to an Amazon S3 location.
587 588 589 590 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 587 def export_earth_observation_job(params = {}, = {}) req = build_request(:export_earth_observation_job, params) req.send_request() end |
#export_vector_enrichment_job(params = {}) ⇒ Types::ExportVectorEnrichmentJobOutput
Use this operation to copy results of a Vector Enrichment job to an Amazon S3 location.
648 649 650 651 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 648 def export_vector_enrichment_job(params = {}, = {}) req = build_request(:export_vector_enrichment_job, params) req.send_request() end |
#get_earth_observation_job(params = {}) ⇒ Types::GetEarthObservationJobOutput
Get the details for a previously initiated Earth Observation job.
769 770 771 772 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 769 def get_earth_observation_job(params = {}, = {}) req = build_request(:get_earth_observation_job, params) req.send_request() end |
#get_raster_data_collection(params = {}) ⇒ Types::GetRasterDataCollectionOutput
Use this operation to get details of a specific raster data collection.
818 819 820 821 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 818 def get_raster_data_collection(params = {}, = {}) req = build_request(:get_raster_data_collection, params) req.send_request() end |
#get_tile(params = {}) ⇒ Types::GetTileOutput
Gets a web mercator tile for the given Earth Observation job.
892 893 894 895 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 892 def get_tile(params = {}, = {}, &block) req = build_request(:get_tile, params) req.send_request(, &block) end |
#get_vector_enrichment_job(params = {}) ⇒ Types::GetVectorEnrichmentJobOutput
Retrieves details of a Vector Enrichment Job for a given job Amazon Resource Name (ARN).
957 958 959 960 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 957 def get_vector_enrichment_job(params = {}, = {}) req = build_request(:get_vector_enrichment_job, params) req.send_request() end |
#list_earth_observation_jobs(params = {}) ⇒ Types::ListEarthObservationJobOutput
Use this operation to get a list of the Earth Observation jobs associated with the calling Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1016 1017 1018 1019 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1016 def list_earth_observation_jobs(params = {}, = {}) req = build_request(:list_earth_observation_jobs, params) req.send_request() end |
#list_raster_data_collections(params = {}) ⇒ Types::ListRasterDataCollectionsOutput
Use this operation to get raster data collections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1065 1066 1067 1068 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1065 def list_raster_data_collections(params = {}, = {}) req = build_request(:list_raster_data_collections, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to the resource.
1094 1095 1096 1097 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1094 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_vector_enrichment_jobs(params = {}) ⇒ Types::ListVectorEnrichmentJobOutput
Retrieves a list of vector enrichment jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1152 1153 1154 1155 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1152 def list_vector_enrichment_jobs(params = {}, = {}) req = build_request(:list_vector_enrichment_jobs, params) req.send_request() end |
#search_raster_data_collection(params = {}) ⇒ Types::SearchRasterDataCollectionOutput
Allows you run image query on a specific raster data collection to get a list of the satellite imagery matching the selected filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1279 1280 1281 1282 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1279 def search_raster_data_collection(params = {}, = {}) req = build_request(:search_raster_data_collection, params) req.send_request() end |
#start_earth_observation_job(params = {}) ⇒ Types::StartEarthObservationJobOutput
Use this operation to create an Earth observation job.
1536 1537 1538 1539 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1536 def start_earth_observation_job(params = {}, = {}) req = build_request(:start_earth_observation_job, params) req.send_request() end |
#start_vector_enrichment_job(params = {}) ⇒ Types::StartVectorEnrichmentJobOutput
Creates a Vector Enrichment job for the supplied job type. Currently, there are two supported job types: reverse geocoding and map matching.
1643 1644 1645 1646 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1643 def start_vector_enrichment_job(params = {}, = {}) req = build_request(:start_vector_enrichment_job, params) req.send_request() end |
#stop_earth_observation_job(params = {}) ⇒ Struct
Use this operation to stop an existing earth observation job.
1666 1667 1668 1669 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1666 def stop_earth_observation_job(params = {}, = {}) req = build_request(:stop_earth_observation_job, params) req.send_request() end |
#stop_vector_enrichment_job(params = {}) ⇒ Struct
Stops the Vector Enrichment job for a given job ARN.
1688 1689 1690 1691 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1688 def stop_vector_enrichment_job(params = {}, = {}) req = build_request(:stop_vector_enrichment_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
The resource you want to tag.
1716 1717 1718 1719 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1716 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
The resource you want to untag.
1742 1743 1744 1745 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1742 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1771 1772 1773 |
# File 'lib/aws-sdk-sagemakergeospatial/client.rb', line 1771 def waiter_names [] end |